==> App-MFILE-WWW-0.097.tar.gz: App-MFILE-WWW-0.097/share/js/core/logout.js <==
// ************************************************************************* 
// Copyright (c) 2014, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// logout.js
//
// function to log out the user
//
"use strict";

define([
    'jquery', 
    'ajax'
], function (
    $, 
    ajax
) {
    return function () {
        var logoutSource = function () {
                var r;
                r = '<br><br><br>';
                r += 'You have been logged out of our humble application<br><br>';
                r += 'Have a lot of fun!<br><br><br>';
                return r;
            },
            logout = function () {
                var rest = {
                        method: 'LOGIN',
                        path: 'logout',
                        body: null
                    },
                    // success callback
                    sc = function (status) {
                        $('#result').html('Logout successful: ' + status.text);
                        $('#mainarea').html(logoutSource());
                        // reload the page -- since the session has been
                        // cleared by the AJAX call, the login dialog will
                        // be displayed
                        setTimeout(function () { location.reload(); }, 1500);
                    },
                    // failure callback
                    fc = null;
                ajax(rest, sc, fc);
            };
        logout();
    }
});

==> App-MFILE-WWW-0.101.tar.gz: App-MFILE-WWW-0.101/share/js/core/logout.js <==
// ************************************************************************* 
// Copyright (c) 2014, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// logout.js
//
// function to log out the user
//
"use strict";

define([
    'jquery', 
    'ajax',
    'cf',
    'html'
], function (
    $, 
    ajax,
    cf,
    html
) {
    return function () {
        var displayLogoutMessage = function () {
                $('#mainarea').html(html.logout());
                setTimeout(function () { location.reload(); }, 1500);
            },
            // if in standalone mode (i.e. if connectToRestServer is false),
            // 'logout' means just reload the page
            logout = cf('connectToRestServer') === 'false'
                ? function () { displayLogoutMessage(); }
                : function () {
                    var rest = {
                            method: 'LOGIN',
                            path: 'logout',
                            body: null
                        },
                        // success callback
                        sc = function (status) {
                            $('#result').html('Logout successful: ' + status.text);
                            displayLogoutMessage();
                        },
                        // failure callback
                        fc = null;
                    ajax(rest, sc, fc);
                };
        logout();
    }
});
